@@ -480,6 +480,8 @@ sub _mk_bash_glue_file {
 
     my $os = _resolve_os();
 
+    my $cli_args = get_prop('cli_args');
+
     print BASH_GLUE <<"CODE";
 
     debug_mod=debug_mod12 
@@ -498,6 +500,8 @@ sub _mk_bash_glue_file {
 
     os=$os
 
+    cli_args='$cli_args'
+
 CODE
 
     close BASH_GLUE;
